#
# spec file for package perl-File-Which
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name File-Which
Name:           perl-File-Which
Version:        1.27
Release:        1.1
Summary:        Perl implementation of the which utility as an API
License:        Artistic-1.0 OR GPL-1.0-or-later
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/P/PL/PLICEASE/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
%{perl_requires}

%description
File::Which finds the full or relative paths to executable programs on the
system. This is normally the function of 'which' utility. 'which' is
typically implemented as either a program or a built in shell command. On
some platforms, such as Microsoft Windows it is not provided as part of the
core operating system. This module provides a consistent API to this
functionality regardless of the underlying platform.

The focus of this module is correctness and portability. As a consequence
platforms where the current directory is implicitly part of the search path
such as Microsoft Windows will find executables in the current directory,
whereas on platforms such as UNIX where this is not the case executables in
the current directory will only be found if the current directory is
explicitly added to the path.

If you need a portable 'which' on the command line in an environment that
does not provide it, install App::pwhich which provides a command line
interface to this API.

%prep
%autosetup  -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644
# MANUAL BEGIN
chmod a+x corpus/test-bin-unix/0
# MANUAL END

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc author.yml Changes README
%license LICENSE

%changelog
* Sun May  9 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.27
  see /usr/share/doc/packages/perl-File-Which/Changes
  1.27      2021-05-07 04:54:31 -0600
  - Production release identical to 1.26_01
  1.26_01   2021-04-27 05:15:20 -0600
  - Fix bug in test where test files sometimes didn't have
    execute permissions (gh#31)
  - Add Env as an explicit test prereq (gh#13, gh#32)
  1.25_01   2021-04-25 07:35:41 -0600
  - Tests should now work when Perl isn't in the PATH (gh#29, gh#30)
* Sat Mar 20 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.24
  see /usr/share/doc/packages/perl-File-Which/Changes
  1.24      2021-03-19 05:50:14 -0600
  - Documentation improvements
  - Moved repository to new github org
* Tue Jan  1 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.23
  see /usr/share/doc/packages/perl-File-Which/Changes
  1.23      2018-12-31 14:28:16 -0500
  - Internally use IS_WIN instead of IS_DOS for DOS/Windows style
    operating systems.  This is 2018 (almost 2019) after all.
    IS_DOS is now an alias for IS_WIN, although these are not public
    interfaces so you shouldn't be using them anyway.
* Sat Sep  9 2017 coolo@suse.com
- updated to 1.22
  see /usr/share/doc/packages/perl-File-Which/Changes
  1.22      2017-09-08 14:08:59 -0400
  - Support for MSYS2 ($^O eq 'msys')
* Tue May 31 2016 coolo@suse.com
- fix test suite with a chmod
* Tue May 31 2016 coolo@suse.com
- updated to 1.21
  see /usr/share/doc/packages/perl-File-Which/Changes
  1.21      2016-03-02 14:20:43 -0500
  - Workaround for nutty cygwin filesystem rules
  1.20      2016-03-01 15:06:54 -0500
  - Fix bug where executable named "0" would not be found (gh#7)
* Wed Jul 22 2015 coolo@suse.com
- updated to 1.19
  see /usr/share/doc/packages/perl-File-Which/Changes
  1.19      2015-07-21 09:23:54 -0400
  - Relax required Perl back to 5.6.x as this module is upriver to
    a large number of modules
  - No non-core requirements back to 5.6.2
* Tue May  5 2015 coolo@suse.com
- updated to 1.18
  see /usr/share/doc/packages/perl-File-Which/Changes
  1.18      2015-05-04 15:35:40 -0400
  - Remove prototypes (gh#6)
* Sat May  2 2015 coolo@suse.com
- updated to 1.17
  see /usr/share/doc/packages/perl-File-Which/Changes
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.16
  see /usr/share/doc/packages/perl-File-Which/Changes
  1.16 Sun 29 Mar 2015
  - Remove use Test::Script from tests that escaped when this requirement
    became optional.
  1.15 Sun 29 Mar 2015
  - Fixed small but important POD error
  1.14 Sun 29 Mar 2015
  - App::pwhich is no longer bundled with File::Which and included
    in its own distribution.
  - pwhich that comes with this distribution is deprecated, and will
    report a warning if you try to use it, you should insted install
    App::pwhich.
  - pwhich that comes with this distribution will not be installed if
    App::pwhich 1.14 or better is already installed.
  - pwhich will be removed from this distribution, but not before
    30 April 2015.
  - Make Test::Script an optional dependency
  1.12 Thu 26 Mar 2015
  - Fixed bug in pwhich introduced in version 1.10 where only the
    first file was searched for
  1.11 Thu 26 Mar 2015
  - Support for relative and fully qualified paths in Unix (gh#2)
  1.10 Thu 26 Mar 2015
  - Test::Script is now a test instead of runtime requirement
    It will be entirely removed as a prerequisite in a subsequent
    release
  - Will now find .exe and .com files (as it should) on cygwin (rt83146)
  - Declared required Perl version is now 5.005003
  - Updated repository and maintainer information.  Source for this
    dist now lives on GitHub
  - New module App::pwhich contains the guts of pwhich.  It will be moved
    into a separate dist in the near future.  pwhich will be deprecated
    and removed from this dist in the near future.
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Tue Jul 13 2010 chris@computersalat.de
- recreated by cpanspec 1.78
- noarch pkg
* Mon Jan 25 2010 anicka@suse.cz
- update to 1.09
  * Set svn:executable for the exe files so cygwin tests work
  * Fixing pwhich
  * Adding a proper test for it
  * Adds a dependency on Test::Script 1.08
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Aug  3 2009 anicka@suse.cz
- update to 1.07
  * CPAN Testers looks good for 1.06_01, moving to production release
  * Taking over this hugely old and very popular module to clean it
  up a bit.
  * Moved from Test.pm to Test::More.
  * Updated Changes
  * Cleaned up some code a bit to make it more readable.
  * Added an explicit minimum Perl version
  * Changed platform detection code to constants for less code size
  and compile-time if () optimisation.
  * Removed non-leading tabs and other whitespace nigglies.
* Wed Dec 20 2006 anicka@suse.cz
- package created (initial version 0.05)
